@@ -307,6 +307,7 @@ pre_get_info(struct ctl_context *ctx)
     ovsdb_idl_add_column(ctx->idl, &sbrec_port_binding_col_chassis);
     ovsdb_idl_add_column(ctx->idl, &sbrec_port_binding_col_datapath);
     ovsdb_idl_add_column(ctx->idl, &sbrec_port_binding_col_up);
+    ovsdb_idl_add_column(ctx->idl, &sbrec_port_binding_col_mirror_rules);
 
     ovsdb_idl_add_column(ctx->idl, &sbrec_logical_flow_col_logical_datapath);
     ovsdb_idl_add_column(ctx->idl, &sbrec_logical_flow_col_logical_dp_group);
@@ -335,6 +336,7 @@ pre_get_info(struct ctl_context *ctx)
     ovsdb_idl_add_column(ctx->idl, &sbrec_mac_binding_col_mac);
 
     ovsdb_idl_add_column(ctx->idl, &sbrec_load_balancer_col_datapaths);
+    ovsdb_idl_add_column(ctx->idl, &sbrec_load_balancer_col_datapath_group);
     ovsdb_idl_add_column(ctx->idl, &sbrec_load_balancer_col_vips);
     ovsdb_idl_add_column(ctx->idl, &sbrec_load_balancer_col_name);
     ovsdb_idl_add_column(ctx->idl, &sbrec_load_balancer_col_protocol);
@@ -826,6 +828,21 @@ cmd_lflow_list_chassis(struct ctl_context *ctx, struct vconn *vconn,
     }
 }
 
+static bool
+datapath_group_contains_datapath(const struct sbrec_logical_dp_group *g,
+                                 const struct sbrec_datapath_binding *dp)
+{
+    if (!g || !dp) {
+        return false;
+    }
+    for (size_t i = 0; i < g->n_datapaths; i++) {
+        if (g->datapaths[i] == dp) {
+            return true;
+        }
+    }
+    return false;
+}
+
 static void
 cmd_lflow_list_load_balancers(struct ctl_context *ctx, struct vconn *vconn,
                               const struct sbrec_datapath_binding *datapath,
@@ -843,6 +860,10 @@ cmd_lflow_list_load_balancers(struct ctl_context *ctx, struct vconn *vconn,
                     break;
                 }
             }
+            if (lb->datapath_group && !dp_found) {
+                dp_found = datapath_group_contains_datapath(lb->datapath_group,
+                                                            datapath);
+            }
             if (!dp_found) {
                 continue;
             }
@@ -861,6 +882,11 @@ cmd_lflow_list_load_balancers(struct ctl_context *ctx, struct vconn *vconn,
                 print_vflow_datapath_name(lb->datapaths[i], true,
                                           &ctx->output);
             }
+            for (size_t i = 0; lb->datapath_group
+                               && i < lb->datapath_group->n_datapaths; i++) {
+                print_vflow_datapath_name(lb->datapath_group->datapaths[i],
+                                          true, &ctx->output);
+            }
         }
 
         ds_put_cstr(&ctx->output, "\n  vips:\n");
@@ -879,21 +905,6 @@ cmd_lflow_list_load_balancers(struct ctl_context *ctx, struct vconn *vconn,
     }
 }
 
-static bool
-datapath_group_contains_datapath(const struct sbrec_logical_dp_group *g,
-                                 const struct sbrec_datapath_binding *dp)
-{
-    if (!g || !dp) {
-        return false;
-    }
-    for (size_t i = 0; i < g->n_datapaths; i++) {
-        if (g->datapaths[i] == dp) {
-            return true;
-        }
-    }
-    return false;
-}
-
 static void
 sbctl_lflow_add(struct sbctl_lflow **lflows,
                 size_t *n_flows, size_t *n_capacity,
@@ -1233,10 +1244,10 @@ static void
 delete_connections(struct ctl_context *ctx)
 {
     const struct sbrec_sb_global *sb_global = sbrec_sb_global_first(ctx->idl);
-    const struct sbrec_connection *conn, *next;
+    const struct sbrec_connection *conn;
 
     /* Delete Manager rows pointed to by 'connection_options' column. */
-    SBREC_CONNECTION_FOR_EACH_SAFE(conn, next, ctx->idl) {
+    SBREC_CONNECTION_FOR_EACH_SAFE (conn, ctx->idl) {
         sbrec_connection_delete(conn);
     }
 
@@ -1421,8 +1432,8 @@ static const struct ctl_table_class tables[SBREC_N_TABLES] = {
     [SBREC_TABLE_HA_CHASSIS_GROUP].row_ids[0]
     = {&sbrec_ha_chassis_group_col_name, NULL, NULL},
 
-    [SBREC_TABLE_HA_CHASSIS].row_ids[0]
-    = {&sbrec_ha_chassis_col_chassis, NULL, NULL},
+    [SBREC_TABLE_MIRROR].row_ids[0]
+    = {&sbrec_mirror_col_name, NULL, NULL},
 
     [SBREC_TABLE_METER].row_ids[0]
     = {&sbrec_meter_col_name, NULL, NULL},
@@ -1450,6 +1461,9 @@ static const struct ctl_table_class tables[SBREC_N_TABLES] = {
 
     [SBREC_TABLE_LOAD_BALANCER].row_ids[0]
     = {&sbrec_load_balancer_col_name, NULL, NULL},
+
+    [SBREC_TABLE_CHASSIS_TEMPLATE_VAR].row_ids[0]
+    = {&sbrec_chassis_template_var_col_chassis, NULL, NULL},
 };
 
 static const struct ctl_command_syntax sbctl_commands[] = {
